@@ -1,4 +1,4 @@
-/* $Id: milter-regex.c,v 1.14 2003/12/09 21:11:15 dhartmei Exp $ */
+/* $Id: milter-regex.c,v 1.16 2004/01/04 00:22:59 dhartmei Exp $ */
 
 /*
  * Copyright (c) 2003 Daniel Hartmeier
@@ -30,7 +30,7 @@
  *
  */
 
-static const char rcsid[] = "$Id: milter-regex.c,v 1.14 2003/12/09 21:11:15 dhartmei Exp $";
+static const char rcsid[] = "$Id: milter-regex.c,v 1.16 2004/01/04 00:22:59 dhartmei Exp $";
 
 #include <sys/types.h>
 #include <sys/socket.h>
@@ -67,9 +67,11 @@ static void	 usage(void);
 static void	 reload_ruleset(void);
 void		 msg(int, const char *, ...);
 
-#define OCONN	"unix:/var/spool/milter-regex"
-#define	RCODE	"554"
-#define XCODE	"5.7.1"
+#define OCONN		"unix:/var/spool/milter-regex"
+#define RCODE_REJECT	"554"
+#define RCODE_TEMPFAIL	"451"
+#define XCODE_REJECT	"5.7.1"
+#define XCODE_TEMPFAIL	"4.7.1"
 
 #ifdef LINUX
 #define	ST_MTIME st_mtime
@@ -145,11 +147,14 @@ setreply(SMFICTX *ctx, const struct rule *rule, const char *fmt, ...)
 	vsnprintf(m + strlen(m), sizeof(m) - strlen(m), fmt, ap);
 	va_end(ap);
 	msg(LOG_INFO, "%s", m);
-	if (rule->action == SMFIS_REJECT ||
-	    rule->action == SMFIS_TEMPFAIL)
-		if (smfi_setreply(ctx, RCODE, XCODE, (char *)rule->message) !=
-		    MI_SUCCESS)
-			msg(LOG_ERR, "smfi_setreply");
+	if (rule->action == SMFIS_REJECT &&
+	    smfi_setreply(ctx, RCODE_REJECT, XCODE_REJECT,
+	    (char *)rule->message) != MI_SUCCESS)
+		msg(LOG_ERR, "smfi_setreply");
+	if (rule->action == SMFIS_TEMPFAIL &&
+	    smfi_setreply(ctx, RCODE_TEMPFAIL, XCODE_TEMPFAIL,
+	    (char *)rule->message) != MI_SUCCESS)
+		msg(LOG_ERR, "smfi_setreply");
 }
 
 static sfsistat
